      SUBROUTINE CHRCUR(VE,VM,AP,BP,N,RADB,SLANT,AKP,AKF,ALINC,LUNIT)
C
C  Currents File of Circular Corrugated Waveguide Horn
C
C  VE      Voltage magnitude of TE component
C  VM      Voltage magnitude of TM component
C          VM/VE = Hybrid mode ratio
C          If VM = 0, TE mode horn
C          If VE = 0, TM mode horn
C  AP      Amplitude of cosinusoidal circumferentially-varying field
C  BP      Amplitude of sinusoidal circumferentially-varying field
C  N       Order of circumferentially-varying field
C  RADB    Outer radius (m)
C  SLANT   Slant radius of horn
C  AKP     Radial component propagation constant
C  AKF     Propagation constant in free space
C  ALINC   Length increment for current patches
C  NR      Number of points in radial integrals
C  NP      Number of points in Phi integrals
C  LUNIT   Logical unit of random access file for currents
C
      COMPLEX CURJ(3),CURM(3),QUAD,VE,VM,AP,BP,ER,EP,HR,HP,CJ,
     1 PSI,PHI
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1)),(FREC(14),CURM(1))
      DATA PI/3.141592654/,CJ/(0.,1.)/,ZZ/376.73/
      AKZ=AKF**2-AKP**2
C ------------- Check for cutoff
      IF(AKZ.LE.0.)RETURN
      AKZ=SQRT(AKZ)
      CURJ(3)=0.
      CURM(3)=0.
      POWER=0.
      NR=RADB/ALINC+.5
      DR=RADB/NR
      FREC(3)=0.
      PK=AKF
      KREC=1
C ------------- Loop over radius
      DO 2 J=1,NR
      RAD=(FLOAT(J-1)+.5)*DR
      BJ=BESSJN(N,RAD*AKP)
      BJP=BESJPR(N,RAD*AKP)
C ------------- Find differential area
      R1=RAD-DR/2.
      R2=RAD+DR/2.
C ------------- Quadratic phase factor
      S=AKF*RAD**2/SLANT/2.
      QUAD=CMPLX(COS(S),-SIN(S))
C ------------- Loop over Phi
      NP=2.*PI*RAD/ALINC+.5
      DP=2.*PI/NP
      DO 1 I=1,NP
      PH=FLOAT(I-1)*DP
C ------------- Circumferential variation
      PSI=AP*COS(N*PH)+BP*SIN(N*PH)
      PHI=BP*COS(N*PH)-AP*SIN(N*PH)
C ------------- Rho and Phi components
      ER=-CJ*ZZ*PSI*(AKZ*BJP*VM+AKF*N*BJ*VE/RAD/AKP)/AKP*QUAD
      EP=-CJ*ZZ*PHI*(AKZ*N*VM*BJ/RAD/AKP+VE*AKF*BJP)/AKP*QUAD
      HR=CJ*PHI*(AKF*N*VM*BJ/RAD/AKP+AKZ*VE*BJP)/AKP*QUAD
      HP=-CJ*PSI*(AKF*BJP*VM+AKZ*N*BJ*VE/RAD/AKP)/AKP*QUAD
C ------------- Differential area and position
      FREC(4)=DP*(R2**2-R1**2)/2.
      FREC(1)=RAD*COS(PH)
      FREC(2)=RAD*SIN(PH)
C ------------- Normalized magnetic and electric currents * Area
      CURJ(1)=-(HR*SIN(PH)+HP*COS(PH))*FREC(4)
      CURJ(2)=(HR*COS(PH)-HP*SIN(PH))*FREC(4)
      CURM(1)=(ER*SIN(PH)+EP*COS(PH))*FREC(4)
      CURM(2)=-(ER*COS(PH)-EP*SIN(PH))*FREC(4)
C ------------- Normalized aperture power * Area
      POWER=POWER+(CABS(CURM(2)*CURJ(1))
     1 +CABS(CURM(1)*CURJ(2)))/FREC(4)
      KREC=KREC+1
    1 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    2 CONTINUE
      CURN=SQRT(POWER)
C ------------- Normalize aperture power to 1 watt
      DO 3 I=2,KREC
      READ(LUNIT,REC=I)(FREC(NN),NN=1,19)
      CURM(1)=CURM(1)/CURN
      CURM(2)=CURM(2)/CURN
      CURJ(1)=CURJ(1)/CURN
      CURJ(2)=CURJ(2)/CURN
    3 WRITE(LUNIT,REC=I)(FREC(NN),NN=1,19)
      IBUF(1)=KREC-1
      IBUF(2)=0
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
