      SUBROUTINE COSPAT(NAP,THETA,PHI,BNE,BNH,POL,ETHETA,EPHI)
C
C  Pattern approximation  I: E = cos(Theta/2)**N
C                        II: E = cos(Theta)**N
C
C  NAP      Pattern approximation number
C  THETA    Pattern angle (radians)
C  PHI      Pattern angle (radians)
C  BNE      Exponent in E plane
C  BNH      Exponent in H plane
C  POL      Polarization: 0 Linear, -1 RHC, +1 LHC
C  ETHETA   Theta component  V/m for 1 watt radiated power at 1 m.
C  EPHI     Phi component    V/m for 1 watt radiated power at 1 m.
C
      COMPLEX ETHETA,EPHI
      DATA GCONS/.1826374/,SQ2/1.4142135/
C ------------------- GCONS = SQRT(4*PI/376.73)
      DE=NAP*(NAP*BNE+1.)
      DH=NAP*(NAP*BNH+1.)
      DIRECT=2.*DE*DH/(DE+DH)
      CT=COS(THETA*NAP/2.)
      IF(CT.LE.0.)THEN
      EE=0.
      ELSE
C ------------------- Elliptical beam approximation
      EE=SQRT(CT**(2.*BNE)*COS(PHI)**2+CT**(2.*BNH)*SIN(PHI)**2)
      ENDIF
C ------------------- Adjust to V/m for 1 w. Input at radius = 1 m.
      EE=EE*SQRT(DIRECT)/GCONS
      IF(POL.EQ.0.)THEN
C ------------------- Linear polarization, X-axis directed
      ETHETA=EE*COS(PHI)
      EPHI=-EE*SIN(PHI)
      ELSE
C ------------------- Circular polarization, Phase = 0 at Phi = 0
      ETHETA=EE*CMPLX(COS(PHI),POL*SIN(PHI))/SQ2
      EPHI=CMPLX(0.,POL)*ETHETA
      ENDIF
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
