      SUBROUTINE NFPATI(XC,XF,EFIELD,HFIELD)
C
C  Near field pattern from currents in common for image in gr.pl.
C  with dielectric slab to top surface at Z = 0
C
C  XC(3)     Position of center of currents
C  XF(3)     Field point (meters)
C  EFIELD    Electric field (V/m)
C  HFIELD    Magnetic field
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,6000)
      COMMON /CURRENJ/CURJA(3,6000)
      COMMON /CURRENM/CURMA(3,6000)
      COMMON /DIELECT/ERS,THS,URS,ITEM
C
C  Dielectric slab common: /DIELECT/
C  ERS	  Dielectric constant (complex)
C	  ER*cmplx(1.,-(loss tangent)) or
C	  cmplx(ER,-(conductivity(S/m))/(2*pi*8.854185e-12*frequency))
C  THS	  Thickness (m)
C  URS	  Relative permeability
C  ITEM   If 1, use TEM approximation. 0, infinite slab, -1 actual
C
      COMPLEX CURJA,CURMA,CURJ(3),CURM(3),EFIELD(3),HFIELD(3),EF(3),
     1 HF(3),CONJ,CONM,GEJ(3,3),GHJ(3,3),EFIEL(3),HFIEL(3),HIN,EIN,
     2 ZSTM,ZSTE,GTM,GTE,ERS,PZM,ZMTE,ZMTM
      DIMENSION XS(3),XF(3),XC(3),XB(3),UI(3),PN(3),XBB(3)
      DATA CC/.2997925/,PI/3.141592654/,EPS/8.854185E-3/,
     1 PN/0.,0.,1./,ZS/376.73/
C ------------- -j*2*Pi*Frequency*Mu  ------ electric field factor
      CONJ=CMPLX(0.,-PKC*CC*400.*PI)
C ------------- -j*2*Pi*Frequency*epsilon -- magnetic field factor
      CONM=CMPLX(0.,-PKC*CC*EPS)
      DO 1 I=1,3
      EFIELD(I)=0.
    1 HFIELD(I)=0.
C --------- Loop on current patches
      DO 5 I=1,NCUR
      DO 2 J=1,3
      EFIEL(J)=0.
      HFIEL(J)=0.
      XS(J)=POSC(J,I)+XC(J)
      CURJ(J)=CURJA(J,I)
    2 CURM(J)=CURMA(J,I)
      XS(3)=-XS(3)
C --------- Vector from image to field point
      CALL VLINC(1.,XF,-1.,XS,XB)
      XBL=SQRT(DOT(XB,XB))
      DO 6 J=1,3
    6 UI(J)=XB(J)/XBL
C --------- Plane of incidence normal: PN plane normal, UI Reflection
      CALL CROSS(PN,UI,XB)
      XBL=SQRT(DOT(XB,XB))
      DO 7 J=1,3
    7 XB(J)=XB(J)/XBL
      CALL GREJC(XF,XS,PKC,GEJ)
      CALL GRHJC(XF,XS,PKC,GHJ)
      IF(NCTYP.LT.2)THEN
C --------- Electric currents available
      CALL CMTMUL(GEJ,CURJ,EF)
      CALL CMTMUL(GHJ,CURJ,HF)
      DO 3 J=1,3
      HFIEL(J)=HFIEL(J)+HF(J)
    3 EFIEL(J)=EFIEL(J)+EF(J)*CONJ
      ENDIF
      IF(NCTYP.NE.1)THEN
C --------- Magnetic currents available
      CALL CMTMUL(GEJ,CURM,HF)
      CALL CMTMUL(GHJ,CURM,EF)
      DO 4 J=1,3
      EFIEL(J)=EFIEL(J)-EF(J)
    4 HFIEL(J)=HFIEL(J)+HF(J)*CONM
      ENDIF
      HIN=0.
      EIN=0.
C --------- Project Electric & magnetic fields on plane of incidence
      DO 8 J=1,3
      HIN=HIN+HFIEL(J)*XB(J)
    8 EIN=EIN+EFIEL(J)*XB(J)
C --------- Incident wave impedances
      ZTM=ZS*UI(3)
      ZTE=ZS/UI(3)
      PZM=PKC*CSQRT((ERS*URS-1.)+UI(3)**2)
      ZMTM=ZS*PZM/PKC/ERS
      ZMTE=ZS*PKC*URS/PZM
      IF(ITEM.EQ.1)THEN
      ZSTM=ZS*CSIN(PKC*THS*CSQRT(ERS))/CCOS(PKC*THS*CSQRT(ERS))*
     1 CMPLX(0.,-1.)/CSQRT(ERS)
      ZSTE=ZSTM
      ELSE IF(ITEM.EQ.-1)THEN
      ZSTM=ZMTM*CSIN(PZM*THS)/CCOS(PZM*THS)*CMPLX(0.,-1.)
      ZSTE=ZMTE*CSIN(PZM*THS)/CCOS(PZM*THS)*CMPLX(0.,-1.)
      ELSE IF(ITEM.EQ.0)THEN
      ZSTM=ZMTM
      ZSTE=ZMTE
      ENDIF
C --------- Find the reflection coefficients of two polarizations
      GTM=(ZTM-ZSTM)/(ZTM+ZSTM)
      GTE=(ZSTE-ZTE)/(ZSTE+ZTE)
C --------- Reduce reflected fields
      HIN=HIN*GTM
      EIN=EIN*GTE
C --------- Find reflected wave orthogonal polarization direction
      CALL CROSS(UI,XB,XBB)
C --------- Find total fields from projection on output polarizations
      DO 9 J=1,3
      EFIELD(J)=EFIELD(J)+XB(J)*EIN+XBB(J)*HIN*ZS
    9 HFIELD(J)=HFIELD(J)+XB(J)*HIN-XBB(J)*EIN/ZS
    5 CONTINUE
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
