      PROGRAM po06
C
C  FORTRAN repeat of example: Aperture Fields on Sphere from
C  Incremental electric dipole
C
      COMMON /CURRENP/NCUR,NCTYP,PKC,POSC(3,2000)
      COMMON /CURRENJ/CURJA(3,2000)
      COMMON /CURRENM/CURMA(3,2000)
C
C  CURRENT Common
C
C  NCUR     Number of points
C  NCTYP    Current types: 0 both, 1 electric only, 2 magnetic only
C  PKC      Propagation constant (1./meters)
C  POSC     Position of current element (meters)
C  CURJA    Electric current * area rectangular components (complex)
C  CURMA    Magnetic current * area rectangular components (complex)
C
      COMPLEX CURJA,CURMA,ETHETA,EPHI
      DIMENSION ANGLE(361),FIELD(361),FAR(361),XC(3),XB(1)
      EXTERNAL BLOCKN
      DATA XC/0.,0.,0./,TR/.01745329/,GCONS/.182637/
C ------- Open random access file for currents
      OPEN(19,FILE='PO01.DAT',ACCESS='DIRECT',RECL=76)
C ------- Create file with currents
      CALL ELECC(19)
      CALL CURCOM(19)
      WRITE(6,1)
    1 FORMAT(' Enter sphere radius (wavelengths) ',$)
      READ(5,*)RADIUS
      WRITE(6,2)
    2 FORMAT(' Enter length of patch increments ',$)
      READ(5,*)ALINC
      IF(NT*NP.GT.2000)STOP
      PHI=0.
C ------- Calculate far field of incremental dipole
      DO 3 I=1,361
      ANGLE(I)=I-1
      THETA=ANGLE(I)*TR
      CALL FFPATR(XC,BLOCKN,XB,THETA,PHI,ETHETA,EPHI)
      FAR(I)=GCONS*CABS(ETHETA)
      IF(FAR(I).GT.1.E-12)THEN
      FAR(I)=20.*ALOG10(FAR(I))
      ELSE
      FAR(I)=-240.
      ENDIF
    3 CONTINUE
C -------- Create sphere geometry file
      CALL SPHGEO(RADIUS,ALINC,19,2)
C -------- Find aperture currents on sphere
      PK=PKC
      CALL SPHCUR(PK,BLOCKN,XB,19)
      CALL CURCOM(19)
C -------- Calculate fields from sphere currents
    6 WRITE(6,5)
    5 FORMAT(' Enter Phi ',$)
      READ(5,*)PHI
      IF(PHI.LT.0)STOP
      DO 4 I=1,361
      THETA=ANGLE(I)*TR
      CALL FFPATR(XC,BLOCKN,XB,THETA,PHI,ETHETA,EPHI)
      FIELD(I)=GCONS*CABS(ETHETA)
      IF(FIELD(I).GT.1.E-12)THEN
      FIELD(I)=20.*ALOG10(FIELD(I))
      ELSE
      FIELD(I)=-240
      ENDIF
    4 CONTINUE
      CALL PLOT(ANGLE,FAR,361)
      CALL PLOT(ANGLE,FIELD,361)
      GOTO6
      END


      SUBROUTINE ELECC(LUNIT)
C
C  Electric current element
C
C  LUNIT   Logical unit of random access file with currents
C
      DIMENSION FREC(19)
      INTEGER*4 IBUF(19)
      COMPLEX CURJ(3)
      EQUIVALENCE (IBUF(3),PK),(FREC(8),CURJ(1))
      DATA PI/3.14159265/
      PK=2.*PI
C ----------- Write first record: # points, current type, Propagation
      IBUF(1)=1
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      CURJ(1)=0.
      CURJ(2)=0.
      CURJ(3)=SQRT(3./(2.*PI*376.73))
      FREC(1)=0.
      FREC(2)=0.
      FREC(3)=0.
      WRITE(LUNIT,REC=2)(FREC(NN),NN=1,19)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
