      SUBROUTINE SUBGEO(DIA,A,B,OFFSET,TYPE,VP,ALINC,LUNIT)
C
C  Offset Subreflector Geometry for Currents File
C  Polar Grid
C
C  DIA     Diameter of projected reflector
C  A       Denominator factor of Z
C  B       Denominator factor of X & Y
C  OFFSET  Offset (center of circular aperture in X-Y plane)
C  TYPE    1) Hyperboloid (Cassegrain)  2) Ellipsoid (Gregorian)
C  VP(3)   Location of hyperboloid (ellipsoid) center
C
C  Note:   Hyperboloid (ellipsoid) axis along Z-axis
C          and located on positive Z-axis
C  ALINC   Current patch increment
C  LUNIT   Logical unit of random access file for currents
C
      DIMENSION VP(1),FREC(19),PP(3),OFFSET(2)
      INTEGER*4 IBUF(19)
      DATA PI/3.14159654/
      NR=DIA/ALINC/2.+.5
      HR=DIA/2./NR
      KREC=1
C  ------------- Loop over radius
      DO 2 J=1,NR
      RAD=(FLOAT(J-1)+.5)*HR
C  ------------- Find differential area on aperture plane
      R1=RAD-HR/2.
      R2=RAD+HR/2.
      AREA=(R2**2-R1**2)/2.
      NP=2.*PI*RAD/ALINC+.5
      NP=NP/4
      NP=(NP+1)*4
      HP=2.*PI/NP
C  ------------- Loop over Phi
      DO 1 I=1,NP
      PH=FLOAT(I-1)*HP
      PP(1)=OFFSET(1)+RAD*COS(PH)
      PP(2)=OFFSET(2)+RAD*SIN(PH)
      RP=SQRT(PP(1)**2+PP(2)**2)
      PP(3)=A*SQRT(1.-(RP/B)**2*(-1.)**TYPE)
C  ------------- Find unit normal
      IF(TYPE.EQ.1)CALL HYPNM(PP,A,B,FREC(5))
      IF(TYPE.EQ.2)CALL ELLNM(PP,A,B,FREC(5))
C  ------------- Adjust area
      FREC(4)=AREA*HP/ABS(FREC(7))
      CALL VLINC(1.,VP,1.,PP,FREC)
      KREC=KREC+1
    1 WRITE(LUNIT,REC=KREC)(FREC(NN),NN=1,19)
    2 CONTINUE
      IBUF(1)=KREC-1
      IBUF(2)=1
      WRITE(LUNIT,REC=1)(IBUF(NN),NN=1,19)
      RETURN
      END
      SUBROUTINE HYPNM(PO,A,B,AN)
C 
C  Normal of Hyperboloid
C 
C  Hyperboloid coordinates for centered figure
C  PO  Position on Hyperboloid
C  A   Denominator factor of Z
C  B   Denominator factor of X & Y
C  AN  Normalized Normal Vector 
C 
C  The Hyperboloid is axisymmetric about Z axis 
C 
      DIMENSION PO(3),AN(3) 
      DEN=SQRT(PO(1)*PO(1)+PO(2)*PO(2)+(PO(3)*B*B/(A*A))**2)
      AN(1)=PO(1)/DEN
      AN(2)=PO(2)/DEN
      AN(3)=-PO(3)*(B/A)**2/DEN
      RETURN
      END 
      SUBROUTINE ELLNM(PO,A,B,AN)
C 
C  Inward Normal of Ellipsoid 
C 
C  Ellipsoid coordinates for centered figure
C  PO  Position on Ellipsoid
C  A   Denominator factor of Z
C  B   Denominator factor of X & Y
C  AN  Normalized Normal Vector 
C 
C  The Ellipsoid is axisymmetric about Z axis 
C 
      DIMENSION PO(3),AN(3) 
      DEN=SQRT(PO(1)*PO(1)+PO(2)*PO(2)+(PO(3)*B*B/(A*A))**2)
      AN(1)=-PO(1)/DEN
      AN(2)=-PO(2)/DEN
      AN(3)=-PO(3)*(B/A)**2/DEN
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END 
