      SUBROUTINE VGREJN(XF,XS,PK,CUR,E)
C
C  Radiative Near field Vector Green's Function
C
C  Vector Green's function between source current density: J
C  and electric field: E when multiplied by -j(2*pi*frequency)*mu
C  Vector Green's function between source current magnetic density: M
C  and the magnetic field: H when multiplied by -j(2*Pi*freq*epsilon)
C
C  XF(3)    Field point (units must match PK)
C  XS(3)    Source point (units must match PK)
C  PK       Propagation constant = 2*Pi/wavelength
C  CUR(3)   Rectangular coordinates of current (complex)
C           When summing in an integration, use current density times
C           area of the surface patch or current times length for a
C           filament.  Use meters**2 or meters and amps.
C
C  E(3)     Returned electric (magnetic) field rectangular coord.
C
      DIMENSION XF(3),XS(3),RR(3)
      COMPLEX CUR(3),E(3),CONP,COEF
      DATA FPI/12.5663706/
      R=0.
C ---------------- Find relative radius vector
      DO 1 I=1,3
      RR(I)=XF(I)-XS(I)
    1 R=R+RR(I)**2
      R=SQRT(R)
C ---------------- Normalize radius vector
      DO 2 I=1,3
    2 RR(I)=RR(I)/R
      COEF=RR(1)*CUR(1)+RR(2)*CUR(2)+RR(3)*CUR(3)
      PHASE=PK*R
      CONP=CMPLX(COS(PHASE),-SIN(PHASE))/FPI/R
C ---------------- Field components from currents
      DO 3 I=1,3
    3 E(I)=(CUR(I)-RR(I)*COEF)*CONP
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
