      SUBROUTINE VGRHJN(XF,XS,PK,CUR,H)
C
C  Radiative Near field Vector Green's Function
C
C  Vector Green's function between source current density: J
C  and magnetic field: H
C  Vector Green's function between source current magnetic density: M
C  and the electric field: E when multiplied by -1
C
C  XF(3)    Field point (units must match PK)
C  XS(3)    Source point (units must match PK)
C  PK       Propagation constant = 2*Pi/wavelength
C  CUR(3)   Rectangular coordinates of current (complex)
C           When summing in an integration, use current density times
C           area of the surface patch or current times length for a
C           filament.  Use meters**2 or meters and amps.
C
C  H(3)     Returned magnetic (-electric) field rectangular coord.
C
      DIMENSION XF(3),XS(3),RR(3)
      COMPLEX CUR(3),H(3),CONP
      DATA FPI/12.5663706/
      R=0.
C ---------------- Find relative radius vector
      DO 1 I=1,3
      RR(I)=XF(I)-XS(I)
    1 R=R+RR(I)**2
      R=SQRT(R)
C ---------------- Normalize radius vector
      DO 2 I=1,3
    2 RR(I)=RR(I)/R
      PHASE=PK*R
      CONP=CMPLX(0.,PK)*CMPLX(COS(PHASE),-SIN(PHASE))/FPI/R
C ---------------- Field components from currents
      CALL VCROSS(RR,CUR,H)
      DO 3 I=1,3
    3 H(I)=-CONP*H(I)
C ------ Antenna Engineering using Physical Optics, Artech
C ------ Code by T.A. Milligan
      RETURN
      END
