% MATLAB script file for calculating finite range
% effects of line source

lam=1;				% wavelength
k0=2*pi/lam;			% wavenumber

dx=lam;				% inter-sample spacing
Lx=50*lam;			% length of line source
Nx=ceil(Lx/dx);			% number of samples
nx=(1:Nx)';			% Nx by 1 array of samples
xs=(nx-1)*dx-Lx/2;		% Nx by 1 array, x dimensions

rs=[xs zeros(Nx,2)];			% Nx by 3, source positions
Ms=[ones(Nx,1) zeros(Nx,2)]/sqrt(Nx);
					% source magnetic currents

Nf=1000;				% Number of field points
nf=(1:Nf)';				% field point index
dr=2*lam;				% range increment
rf=[zeros(Nf,2) nf*dr];			% Nf by 1 array of ranges

Ef=prop01(rs,Ms,rf,k0);			% boresight field density
Vf=4*pi*Ef(:,2).*rf(:,3);		% boresight field strength		
Pf=20*log10(abs(Vf/max(Vf)));		% boresight power 

plot(rf(:,3)/(2*Lx^2/lam),Pf);grid
xlabel('Range, wavelengths');ylabel('Relative Power, dB')
title('Range Effect on Radiated Power')


%

