% MATLAB script file for calculating finite range
% patterns of line source

lam=1;				% wavelength
k0=2*pi/lam;			% wavenumber

dx=lam;				% inter-sample spacing
Lx=30*lam;			% length of line source
Nx=ceil(Lx/dx);			% number of samples
nx=(1:Nx)';			% Nx by 1 array of samples
xs=(nx-1)*dx-Lx/2;		% Nx by 1 array,x dimensions

rs=[xs zeros(Nx,2)];			% Nx by 3, source pos
Ms=[ones(Nx,1) zeros(Nx,2)]/sqrt(Nx);
					% source magnetic currents

R0=2*(2*Lx^2/lam);			% pattern range
Nf=200;					% Number of field points
nf=(1:Nf)';				% field point index
dth=pi/180*(40)/(Nf-1);			% theta increment
th=-pi/180*20+dth*(nf-1);		% theta, radians
thd=th*180/pi;				% theta, deg
rf=R0*[sin(th) zeros(Nf,1) cos(th)];	% Nf by 1 array of ranges

Ef=prop01(rs,Ms,rf,k0);			% boresight field density
Vf=4*pi*Ef(:,2).*rf(:,3);		% boresight field strength		
Pf=20*log10(abs(Vf/max(Vf)));		% boresight power 

plot(thd,Pf);grid
axis([-20 20 -50 0])
xlabel('Theta, deg');ylabel('Relative Power, dB')
title('Near Field Pattern of Line Source')
text(-17,-9,['Range: ',num2str(R0*lam/Lx^2),' Lx^2/lam'])



%

