% MATLAB script file for calculating far-field
% patterns of two magnetic point sources
% 

lam=1;			% wavelength
k0=2*pi/lam;		% wavenumber

% position vector array, sources
rs=[	0 	0  	 lam/4
	0 	0 	-lam/4	];	
				

dS=[1;1];		% source sampling areas (normalized)
M0=sqrt(6*pi*376.7)/k0;	% nominal magnetic current, Volts/m

% array of mag excitations, V-m
Ms=[	0 	0 	M0
	0	0	M0	];
				

Nf=200;			% Number of field points
nf=(1:Nf)';		% field point index
dth=2*pi/(Nf-1);	% theta increment
th=-pi+dth*(nf-1);	% theta, radians
thd=th*180/pi;		% theta, deg
ph=zeros(Nf,1);		% phi angles

Ef=propff01(rs,Ms,th,ph,k0);	% rad field

PthdB=10*log10(abs(4*pi/2/376.7*Ef(:,1).^2));
				% theta component directivity
PphdB=10*log10(abs(4*pi/2/376.7*Ef(:,2).^2));
				% phi component directivity

plot(thd,PphdB);grid
axis([-180 180 -50 10])
xlabel('Theta, deg');ylabel('Directivity, dBi')
title('Far-Field Pattern of Two Magnetic Point Sources')


%