% MATLAB script file for calculating far-field
% patterns of two magnetic point sources, full propagator

lam=1;			% wavelength
k0=2*pi/lam;		% wavenumber

rs=[	0	0		 lam/4
	0	0		-lam/4	];	
		% position vector array, sources

dS=[1;1];		% source sampling areas (normalized)
M0=sqrt(6*pi*376.7)*lam/2/pi;
				% nom mag current, Volts/m

Ms=[	0 	0 	M0
	0	0	M0	];
				% array of mag excitations, V-m

Nf=200;				% Number of field points
nf=(1:Nf)';				% field point index
dth=2*pi/(Nf-1);		% theta increment
th=-pi+dth*(nf-1);	% theta, radians
thd=th*180/pi;		% theta, deg
ph=zeros(Nf,1);		% phi, deg

R0=1e8;				% range to far field
rf=R0*[cos(ph).*sin(th) sin(ph).*sin(th) cos(th)];

Ef=prop01(rs,Ms,rf,k0);		% radiated E

Efth=Ef(:,1).*cos(ph).*cos(th)...
	 +Ef(:,2).*sin(ph).*cos(th)...
	 -Ef(:,3).*sin(th);		% theta field component
Efph=-Ef(:,1).*sin(ph)+Ef(:,2).*cos(ph);
						% phi component

PthdB=10*log10(abs(4*pi/2/376.7*(Efth.*R0).^2));
				% theta component directivity
PphdB=10*log10(abs(4*pi/2/376.7*(Efph.*R0).^2));
				% phi component directivity

%