% MATLAB script file for calculating far-field 
% patterns of vector electric point source inside
% spherical equivalent surface. 
% PART a: sets up source current and equivalent surface
%

lam=1;			% wavelength
k0=2*pi/lam;		% wavenumber
Z0=376.7;		% free-space characteristic impedance

rs=[0 0 0];		% position vector

J0=lam*sqrt(3/Z0/pi);	% electric source current 
Js=J0.*[0 0 1];	% array of normalized currents

Req=3*lam;		% radius of equivalent surface
dthmax=.5*lam;		% max sampling interval, theta 
dphmax=.5*lam;		% max sampling interval, phi 
Nth=ceil(pi*Req/dthmax+1);	% number of theta samples
dth=pi/(Nth-1);	% actual theta increments

theq=[];		% initialize array of theta angles
pheq=[];		% initialize array of phi angles
dSeq=[];		% initialize array of surface areas

for nn=1:Nth		% iterate over sutface theta angle
  thn=(nn-.5)*dth;	% theta angle
  Nph=ceil(2*pi*Req*abs(sin(thn))/dphmax+1);
	   % array of numbers of phi samples at each theta
  nph=(1:Nph)';		% array of phi indices
  dph=2*pi/Nph;		% actual phi increment
  phn=(nph-.5)*dph;	% array of phi angles
  theq=[theq;thn*ones(Nph,1)];	% array of theta angles
  pheq=[pheq;phn];	% array of phi angles
  dSeqn=2*Req^2*abs(sin(thn)*sin(dth/2))*dph*ones(Nph,1);
  dSeq=[dSeq;dSeqn];	% array of sample surface areas
end

% equivalent surface position vector components:
xeq=Req*cos(pheq).*sin(theq);	% x components 
yeq=Req*sin(pheq).*sin(theq);	% y components
zeq=Req*cos(theq);		% z componetns

req=[xeq yeq zeq];	% equivalent surf pos vectors
uneq=req/Req;		% unit vectors

Neq=length(req);	% number of surface samples

%