% % MATLAB script file for calculating far-field
% patterns of conical horn
%
% PART c: aperture currents
%

global om e0 m0 nph Ra Xs  % vars for function po09fun1

fg=11.803/lam;		% frequency, GHz
om=2*pi*fg*1e9;		% radial frequency, rad/s
m0=4*pi*1e-7*.0254;	% free-space permeability, H/inch
e0=8.854e-12*.0254;	% free-space permittivity, F/inch
Ra=Da/2;		% aperture radius

% find desired root of characteristic equation 

dkrh=(krh2-krh1)/(Nkrh-1); % rho wavenumber increment
nk=(1:Nkrh)';		% rho wavenumber index
krg=krh1+(nk-1)*dkrh;	% rho wavenumbers

Fr=po09fun1(krg); % call characteristic eq.

plot(krg,Fr);grid;axis([min(krg) max(krg) -10 10]) 
xlabel('Radial Wavenumber, rad/inch')
ylabel('F')
[kri Ferr]=ginput;	% select root for fzero solution

krc=fzero('po09fun1',kri);% exact solution, complex
kr=real(krc);		% real part
kz=sqrt(k0^2-kr^2);	% z wavenumbers

JnR=bessel(nph,kr*Ra); % bessel function, 1st kind, nphi
DJnR=-bessel(nph+1,kr*Ra)+nph./kr/Ra.*bessel(nph,kr*Ra);
	% derivative of bessel function, 1st kind, nphi 

ZrTE=om*m0./kr;
ZrTM=kr/om/e0;
Bs=-1/Xs;
Xsn=Xs/Z0;
Bsn=-1/Xsn;
ZrTEn=ZrTE/Z0;
YrTMn=Z0./ZrTM;

gamHE=-kr*k0./kz*Ra/nph.*DJnR./JnR;	% HE mode ratio
gamEH=-1/gamHE;			% EH mode ratio

Jn=bessel(nph,kr*rho);	% bessel function, 1st kind, nphi
DJn=-bessel(nph+1,kr*rho)+nph./kr./rho.*bessel(nph,kr*rho);
	% derivative of bessel function, 1st kind, nphi 

PsTMHE=Ap*cos(nph*phi)+Bp*sin(nph*phi);% TM Psi phi dist
PhTMHE=Bp*cos(nph*phi)-Ap*sin(nph*phi);% TM Phi phi dist
PsTEHE=-Bp*cos(nph*phi)+Ap*sin(nph*phi);% TE Psi phi dist
PhTEHE=Ap*cos(nph*phi)+Bp*sin(nph*phi);% TE Phi phi dist

Lh=Da/2/tan(pi/180*thfd/2);	% length to apex
phA=-k0*(sqrt(rho.^2+Lh^2)-Lh); % aperture phase curvature 
Psz=exp(-i*phA)*I13;		% phase curvature factor 

EzTMHE=gamHE*Z0*Jn.*PsTMHE;	
HrTMHE=-i*om*e0/kr^2*nph./rho*gamHE*Z0.*Jn.*PhTMHE;
HpTMHE=i*om*e0/kr*gamHE*Z0*DJn.*PsTMHE;
ErTMHE=i*kz/kr*gamHE*Z0*DJn.*PsTMHE;
EpTMHE=i*kz/kr^2*nph./rho*gamHE*Z0.*Jn.*PhTMHE;
	
HzTEHE=Jn.*PsTEHE;	
ErTEHE=i*om*m0/kr^2*nph./rho.*Jn.*PhTEHE;
EpTEHE=-i*om*m0/kr*DJn.*PsTEHE;
HrTEHE=i*kz/kr*DJn.*PsTEHE;
HpTEHE=i*kz/kr^2*nph./rho.*Jn.*PhTEHE;

EzHE=EzTMHE;		% total fields
ErHE=ErTMHE+ErTEHE;
EpHE=EpTMHE+EpTEHE;

HzHE=HzTEHE;		
HrHE=HrTMHE+HrTEHE;
HpHE=HpTMHE+HpTEHE;

% total vectorial aperture field

EtHE=(ErHE*I13).*urs+(EpHE*I13).*ups;
HtHE=(HrHE*I13).*urs+(HpHE*I13).*ups;

Ea=EtHE.*Psz;	% total aperture fields
Ha=HtHE.*Psz;	

Ma=cross01(uns,Ea);	% aperture magnetic currents
Ja=-cross01(uns,Ha);	% aperture electric currents

Pm=1/2/Z0*sum(abs(dot01(Ma,Ma'.')).*DSa);	% power
Pe=1/2*Z0*sum(abs(dot01(Ja,Ja'.')).*DSa);

Ms=Ma/sqrt(Pm).*(DSa*I13);	% current in Volt*meter
Js=Ja/sqrt(Pe).*(DSa*I13);	% current in Amp*meter

%