% MATLAB script file for calculating far-field 
% patterns of vector electric point source on circular 
% perfectly-absorbing groundplane
%
% PART c: aperture geometry
% previous m-files: po10a
%

Nths=ceil(pi/2*Req/dthsmax+1);	% number of theta samples, eq 
dths=pi/2/Nths;		% actual theta increments, eq surface

theq=[];		% initialize array of theta angles
pheq=[];		% initialize array of phi angles
dSeq=[];		% initialize array of surface areas

for nths=1:Nths		% iterate over sutface theta angle
  ths=(nths-.5)*dths;	% theta angle
  Nph=ceil(2*pi*Req*abs(sin(ths))/dphsmax+1);
	   % array of numbers of phi samples at each theta
  nph=(1:Nph)';		% array of phi indices
  dph=2*pi/Nph;		% actual phi increment
  phn=(nph-.5)*dph;	% array of phi angles
  theq=[theq;ths*ones(Nph,1)];	% array of theta angles
  pheq=[pheq;phn];	% array of phi angles
  dSeqn=2*Req^2*abs(sin(ths)*sin(dths/2))*dph*ones(Nph,1);
  dSeq=[dSeq;dSeqn];	% array of sample surface areas
end

% equivalent surface position vector components:
xeq=Req*cos(pheq).*sin(theq);	% x components 
yeq=Req*sin(pheq).*sin(theq);	% y components
zeq=Req*cos(theq);		% z componetns

req=[xeq yeq zeq];	% equivalent surf pos vectors
uneq=req/Req;		% unit vectors

Neq=length(req);	% number of surface samples

%