% MATLAB script file for calculating far-field 
% patterns of vector electric point source on circular 
% impedance groundplane
%
% PART d: equivalent surface currents
% previous m-files: po12a, po12b, po12c
%

uts=norm01(req-ones(Neq,1)*rs); % unit vect, source to field
Hs=-propnf01(rs,Js,req,k0);	% source H field
Es=-Z0*cross01(uts,Hs);		% source E field
Jeqd=cross01(uneq,Hs);		% eq direct electric current 
Meqd=-cross01(uneq,Es);		% eq direct magnetic current

ri=[rs(:,1:2) -rs(:,3)];	% image position

uti=norm01(req-ones(Neq,1)*ri);	% unit vect, image to field
uni=norm01(cross01(uti,[0 0 1]));
		% unit vector normal to plane of incidence

kuz=uti(:,3);			% z wavenumber
kux=uti(:,1);			% x wavenumber
kuy=uti(:,2);			% y wavenumber
kut=sqrt(kux.^2+kuy.^2);	% transverse wavenumber

Hi0=-propnf01(rs,Js,[req(:,1:2) -req(:,3)],k0);	
		% raw image fields
Ei0=-Z0*cross01([uti(:,1:2) -uti(:,3)],Hi0);

Hin=dot01(Hi0,uni);     % H field normal to plane of incidence
Ein=dot01(Ei0,uni);     % E field normal to plane of incidence

ZTM=Z0*uti(:,3);	% TMz characteristic impedance 
ZTE=Z0./uti(:,3);	% TEz characteristic impedance

kzm=sqrt(k0^2*(er*mr-1)+(k0*uti(:,3)).^2); 
				% z wavenumber in material
ZmTM=Z0*kzm/k0/er;	% TM material char impedance
ZmTE=Z0*k0*mr./kzm;	% TE material char impedance

ZsTM=-i*ZmTM.*tan(kzm*hc); % TM surface impedance
ZsTE=-i*ZmTE.*tan(kzm*hc); % TE surface impedance

GTM=(ZTM-ZsTM)./(ZTM+ZsTM);	% TM reflection coefficient
GTE=(ZsTE-ZTE)./(ZsTE+ZTE);	% TE reflection coefficient

% equivalent image currents:
JeqiTM=cross01(uneq,((GTM.*Hin)*ones(1,3)).*uni);
MeqiTM=Z0*cross01(uneq,JeqiTM);	 
MeqiTE=-cross01(uneq,((GTE.*Ein)*ones(1,3)).*uni);
JeqiTE=-1/Z0*cross01(uneq,MeqiTE);
Jeqi=JeqiTM+JeqiTE;
Meqi=MeqiTM+MeqiTE;	

Mn=(Meqd+Meqi).*(dSeq*ones(1,3));	% normalized current
Jn=(Jeqd+Jeqi).*(dSeq*ones(1,3)); 	% normalized current

%