% MATLAB script file for calculating far-field 
% patterns of reflector
% 
% PART a: define variables
%

lam=1;		% wavelength
k0=2*pi/lam;	% wavenumber
Z0=376.7;	% free-space characteristic impedance

%____corrugated horn parameters

r0=[0 0 0];		% aperture center position vector

un0=[0 0 -1];		% unit normal of aperture
ut2=[0 1 0];		% unit vector in aperture y dimension
ut1=cross01(ut2,un0);	% unit vector in aperture x dimension

Da=1*lam;	% feed aperture diameter, inches
thfd=10;	% feed conical flare angle, deg
Xs=1e30;	% corrugation reactance

nph=1;		% phi mode number
krh1=0;		% start value, search for rho wavenumber
krh2=8;		% stop value, search for rho wavenumber
Nkrh=1000;	% number of rho wavenumber steps 

Ap=1;		% TM sine mode
Bp=0;		% TM cosine mode

dphm=.15*lam;	% x maximum sampling spacing
drm=.15*lam;	% y maximum sampling spacing

%____reflector parameters

Darx=20*lam;	% elliptical aperture x dimension, inches
Dary=20*lam;	% elliptical aperture y dimension, inches
Fl=Darx*.5;	% parab focal length, inch
xa0=0;		% aperture center x location, inch
ya0=0;		% aperture center y location, inch
zv0=-Fl;	% paraboloid vertex z location, inch

drxmax=.6*lam;	% max allowed x sampling spacing
drymax=.6*lam;	% max allowed y sampling spacing


%____reflector forward patterns

thd1=0;	% theta cut start angle, deg
thd2=180;	% theta stop angle, deg
Nth=261;	% number of theta angles
Nthg=40;	% number of simultaneous angles
phd=0;		% phi angle for theta cut


I13=ones(1,3); % 1 by 3 array of ones

%