% MATLAB script file for calculating far-field 
% patterns of reflector
% 
% PART c: define reflector surface 
%

ax=Darx/2;	% aperture ellipse x half axis
ay=Dary/2;	% aperture ellipse y half axis

Nrx=ceil(Darx/drxmax)+1; % no of sampling x positions
drx=Darx/(Nrx-1);	% actual x sampling increment

xrr=xa0-Darx/2+((1:Nrx)'-1)*drx; % sampling x dimensions

% y aperture limits:
yrmax=ya0+ay*sqrt(1-(xrr-xa0).^2/ax^2);	% lower 
yrmin=ya0-ay*sqrt(1-(xrr-xa0).^2/ax^2);	% upper 

Nryr=ceil(abs(yrmax-yrmin)/drymax)+2; % numbs of y incrmnts
dyr=(yrmax-yrmin)./Nryr; % array of y sampling spacings
Nr=sum(Nryr);		 % tot number of reflector samples

rr=[];
dSr=[];
phrr=[];
 
for nrx=1:Nrx		% iterate over x sampling dimension

  if(nrx/50==ceil(nrx/50));[nrx Nrx],end % iteration counter

  yr=yrmin(nrx)+((1:Nryr(nrx))'-.5)*dyr(nrx);% y coordinates  
  zr=(xrr(nrx)^2+yr.^2)/4/Fl-Fl;	% z coordinates
  rr=[rr;[xrr(nrx)*ones(Nryr(nrx),1) yr zr]];% position vectors

  xlim1=xrr(nrx)+drx/2;		% integral limits for surf area
  xlim2=xrr(nrx)-drx/2;		
  ylim1=yr+dyr(nrx)/2;		
  ylim2=yr-dyr(nrx)/2;		

  Tx11=xlim1/2/Fl;	% terms in surface area calculation
  Tx21=sqrt(Tx11^2+1);		
  Tx31=Fl*(Tx11*Tx21+log(Tx11+Tx21));
  Tx12=xlim2/2/Fl;		
  Tx22=sqrt(Tx12^2+1);		
  Tx32=Fl*(Tx12*Tx22+log(Tx12+Tx22));

  Ty11=ylim1/2/Fl;		
  Ty21=sqrt(Ty11.^2+1);		
  Ty31=Fl*(Ty11.*Ty21+log(Ty11+Ty21));
  Ty12=ylim2/2/Fl;		
  Ty22=sqrt(Ty12.^2+1);		
  Ty32=Fl*(Ty12.*Ty22+log(Ty12+Ty22));

  dSr=[dSr;(Tx31-Tx32)*(Ty31-Ty32)];	% surface areas of samples  
  phrr=[phrr;atan2(yr,xrr(nrx)*ones(Nryr(nrx),1))]; % phi angles

end

alr=atan(2*Fl./vlenr(rr));	% angles between -rho and normals
unr=[-cos(phrr).*cos(alr) -sin(phrr).*cos(alr) sin(alr)];

u2r=unitr(crossr(unr,ones(Nr,1)*[1 0 0])); % second tan unit vect
u1r=crossr(u2r,unr);			% first tangent unit vect

%