% MATLAB script file for calculating far-field 
% patterns of reflector including blockage
% 
% PART f: strut and feed blockage contributions added to 
% 	  reflector patterns
%

nth=(1:Nth)';	% Nth by 1 theta angle index array
dthd=(thd2-thd1)/(Nth-1);	% theta increment, deg
thd=thd1+(nth-1)*dthd;	% Nth by 1 array,theta angles
thr=pi/180*thd;		% in radians

EMb=[];
HJb=[];

for nnth=1:Nthg:Nth % break up thd into smaller arrays
  [nnth Nth]

  thrs=thr(nnth:min([nnth+Nthg-1,Nth])); % theta angles, rad
  phr=pi/180*phd*ones(size(thrs));	 % phi angles, rad

  EMbr=propff01(rb,Mrbr,thrs,phr,k0);	% E field from Mrbr
  HJbr=-propff01(rb,Jrbr,thrs,phr,k0);	% H field from Jrbr

  EMb=[EMb;EMbr];		% cascade thd arrays
  HJb=[HJb;HJbr];	

end

Ethb=EMb(:,1)+HJb(:,2)*Z0;	% theta pol E field
Ephb=EMb(:,2)-HJb(:,1)*Z0; 	% phi pol E field
Erb=sqrt(.5)*(Ethb+i*Ephb);	% RHCP E field
Elb=sqrt(.5)*(Ethb-i*Ephb);	% LHCP E field

EthT=Eth+Ethb;
EphT=Eph+Ephb;
ErT=Er+Erb;
ElT=El+Elb;

Pthb=abs(4*pi/2/Z0*Ethb.^2);
Pphb=abs(4*pi/2/Z0*Ephb.^2);
Prb=abs(4*pi/2/Z0*Erb.^2);
Plb=abs(4*pi/2/Z0*Elb.^2);

PthbdB=10*log10(Pthb);
PphbdB=10*log10(Pphb);
PrbdB=10*log10(Prb);
PlbdB=10*log10(Plb);

PthT=abs(4*pi/2/Z0*EthT.^2);
PphT=abs(4*pi/2/Z0*EphT.^2);
PrT=abs(4*pi/2/Z0*ErT.^2);
PlT=abs(4*pi/2/Z0*ElT.^2);

PthTdB=10*log10(PthT);
PphTdB=10*log10(PphT);
PrTdB=10*log10(PrT);
PlTdB=10*log10(PlT);

%