% MATLAB script file for calculating far-field 
% patterns of Cassegrain reflector 
% 
% PART a: define variables
%

lam=1;		% wavelength
k0=2*pi/lam;	% wavenumber
Z0=376.7;	% free-space characteristic impedance

%____main reflector parameters

Darx=50*lam;	% elliptical aperture x dimension, inches
Dary=50*lam;	% elliptical aperture y dimension, inches

Fl=.35*Darx;	% parab focal length, inch

xa0=0;		% aperture center x location, inch
ya0=0;		% aperture center y location, inch
zv0=-Fl;	% paraboloid vertex z location, inch

drxmax=.5*lam;	% max allowed x sampling spacing
drymax=.5*lam;	% max allowed y sampling spacing


%____secondary reflector parameters

Das=8*lam;	% subreflector diameter, inches
Mags=3.57;	% magnification factor

xs0=0;		% position of subreflector focus
ys0=0;
zs0=0;

dphsm=.5*lam;	% maximum phi sampling spacing
drsm=.5*lam;	% maximum radial sampling spacing


%____feed, main and subreflector positions

eccs=(Mags+1)/(Mags-1);		% subreflector eccentricity
le=Das/2*(16*Fl^2-Darx^2)/8/Fl/Darx;
A1=eccs^2-1;
B1=-2*eccs*le;
C1=le^2-Das^2/4/(eccs^2-1);
as=(-B1+sqrt(B1^2-4*A1*C1))/2/A1;% transverse half axis
bs=as*sqrt(eccs^2-1);		% conjugate half axis

Fs2=2*sqrt(as^2+bs^2);	% distance between hyperbolic focii


%____pyramidal horn parameters

r0=[0 0 -Fs2];	% aperture center position vector
un0=[0 0 1];		% unit normal of aperture
ut2=[0 1 0];		% unit vector in aperture y dimension
ut1=cross01(ut2,un0);	% unit vector in apertue x dimension

wx=2.2*lam;		% aperture x dimension
wy=2.2*lam;		% aperture y)dimension
thxd=.001;		% x-z plane flare angle, deg
thyd=.001;		% y-z plane flare angle, deg

dxm=.25*lam;	% x maximum sampling spacing
dym=.25*lam;	% y maximum sampling spacing

mTEx=[1 0];	% TE x-mode array
mTEy=[0 1];	% TE y-mode array
mTMx=[0];	% TM x-mode array
mTMy=[0];	% TM y-mode array

ITE=[1 -i]*Z0;	% TE current relative excitations
NTE=length(ITE);	% number of TE modes
IITE=ones(size(ITE));	% 1 by NTE array of ones

VTM=[0];		% TM voltage relative excitation
NTM=length(VTM);	% number of TM modes
IVTM=ones(size(VTM));	% 1 by NTM array of ones


%____pattern angles

thd1=0;		% theta cut start angle, deg
thd2=180;	% theta stop angle, deg
Nth=181;	% number of theta angles
Nthg=5;		% number of simultaneous angles
phd=0;		% phi angle for theta cut


I13=ones(1,3); % 1 by 3 array of ones

%
