% MATLAB script file for calculating monostatic RCS of Truncated
% Right-Circular Cone
%
% PART c: induced currents and patterns
%

nth=(1:Nth)';	% Nth by 1 theta angle index array
dthd=(thd2-thd1)/(Nth-1);	% theta increment, deg
thd=thd1+(nth-1)*dthd;	% Nth by 1 array,theta angles
thr=pi/180*thd;		% in radians

EM=[];
HJ=[];

for nth=1:Nth % iterate over angle
  if(nth/40==ceil(nth/40));[nth Nth],end


  thrs=thr(nth); 	% theta angle, rad
  phr=pi/180*phd;	 % phi angle, rad

  ukin=-[[cos(phr) sin(phr)]*sin(thrs) cos(thrs)];
		% incident direction
  uphin=norm01(cross01(ukin,[0 0 1]));	% phi unit vector
  uthin=cross01(uphin,ukin);		% theta unit vector

  PROJ=dot01(ones(Nc,1)*ukin,unc);	
	% projection of incident unit vector on normals
  nnill=find(PROJ<0);	% illuminated samples
  
  PHA=-k0*dot01(ones(Nc,1)*ukin,rc); 	% relative phases
  DSp=DSc.*abs(PROJ);			% projected areas

  E0=exp(-i*PHA)/sqrt(sum(Vin.^2)); 
		% electric field complex amp

 
  Ein=Vin(1)*E0(nnill)*uthin+Vin(2)*E0(nnill)*uphin;
					% incident E field
  Hin=1/Z0*cross01(ones(size(nnill))*ukin,Ein);		
					% incident H field  	

  Jr=cross01(ones(size(nnill))*ukin,Hin);% eq elect currnt 
  Mr=-cross01(ones(size(nnill))*ukin,Ein);
				% eq magnetic current

  Mn=Mr.*(DSc(nnill)*ones(1,3));% normalized current
  Jn=Jr.*(DSc(nnill)*ones(1,3)); % normalized current
  Mrru=Mn;			% re-radiation currents
  Jrru=-Jn;

  % The monostatic RCS is calculated in the same way as 
  % the physical optics far-field patterns, but instead of 
  % normalizing the equivalent currents to unity power,
  % they are normalized to unity insident power density.

  Pine=1/2*Z0*sum(length01(abs(Jrru).^2).*DSp(nnill));
  Pinm=1/2/Z0*sum(length01(abs(Mrru).^2).*DSp(nnill));
  Sine=Pine/sum(DSp(nnill))/.0254^2;
  Sinm=Pinm/sum(DSp(nnill))/.0254^2;
  Mrr=Mrru/sqrt(Sine).*(DSp(nnill)*ones(1,3));
  Jrr=Jrru/sqrt(Sinm).*(DSp(nnill)*ones(1,3));
 
  EMs=propff01(rc(nnill,:),Mrr,thrs,phr,k0);	
			% FF electric field from Mn
  HJs=-propff01(rc(nnill,:),Jrr,thrs,phr,k0);
			% FF magnetic field from Jn
  EM=[EM;EMs];		% cascade thd arrays
  HJ=[HJ;HJs];	

end

Eth=EM(:,1)+HJ(:,2)*Z0;		% theta pol E field
Eph=EM(:,2)-HJ(:,1)*Z0; 	% phi pol E field

Pth=abs(4*pi/2/Z0*Eth.^2);
Pph=abs(4*pi/2/Z0*Eph.^2);

PthdB=10*log10(Pth);
PphdB=10*log10(Pph);

%