function Ef=prop01(rs,Ms,rf,k0)

%	rs	Ns by 3 array, source position vectors
%	Ms	Ns by 3 array, source currents
% 	rf	Nf by 3 array, field position vectors
%	k0	wavenumber, radians/inch
%
%	Ns	number of source points
%	Nf	number of field points
%

Ns=length(rs(:,1));	% number of source points
Nf=length(rf(:,1));	% number of field points
INs=ones(Ns,1);		% Ns by 1 array of ones
INf=ones(Nf,1);		% Nf by 1 array of ones	
xt=rf(:,1)*INs'-INf*rs(:,1)';  % Nf by Ns, transport x 
yt=rf(:,2)*INs'-INf*rs(:,2)';  % Nf by Ns, transport y 
zt=rf(:,3)*INs'-INf*rs(:,3)';  % Nf by Ns, transport z

Rt=sqrt(xt.^2+yt.^2+zt.^2);   % transport lengths
g0=1/4/pi./Rt.*exp(i*k0*Rt); % scalar Green's function
G0=(1../Rt-i*k0).*g0./Rt;     % common factor

Gxy=-G0.*zt;  	% Nf by Ns, x-y Green's   
Gxz=G0.*yt;   	% Nf by Ns, x-z Green's 
Gyz=-G0.*xt;  	% Nf by Ns, y-z Green's 

% The rest of the Green's functions are not needed:
%		Gxx=zeros(Nf,Ns)
%		Gyx=-Gxy
% 		Gyy=Gxx
%		Gzx=-Gxz
%		Gzy=-Gyz
%		Gzz=Gxx

Ex=Gxy*Ms(:,2)+Gxz*Ms(:,3);   % Nf by 1, E x component
Ey=-Gxy*Ms(:,1)+Gyz*Ms(:,3);  % Nf by 1, E y component
Ez=-Gxz*Ms(:,1)-Gyz*Ms(:,2);  % Nf by 1, E z component

Ef=[Ex Ey Ez];		% Nf by 3 array, radiated E

%
