function Hf=prop02(rs,Ms,rf,k0)

% gives Hf from Ms when multiplied by k0*Y0, and Ef from 
% Js when multiplied by k0*Z0;

%	rs	Ns by 3 array, source position vectors
%	Ms	Ns by 3 array, source currents
% 	rf	Nf by 3 array, field position vectors
%	k0	wavenumber, radians/inch
%
%	Ns	number of source points
%	Nf	number of field points
%

Ns=length(rs(:,1));	% number of source points
Nf=length(rf(:,1));	% number of field points

INs=ones(Ns,1);		% Ns by 1 array of ones
INf=ones(Nf,1);		% Nf by 1 array of ones	

xt=rf(:,1)*INs'-INf*rs(:,1)';  % Nf by Ns, transport x 
yt=rf(:,2)*INs'-INf*rs(:,2)';  % Nf by Ns, transport y 
zt=rf(:,3)*INs'-INf*rs(:,3)';  % Nf by Ns, transport z

Rt=sqrt(xt.^2+yt.^2+zt.^2);   % transport lengths
g0=1/4/pi./Rt.*exp(i*k0*Rt);  % scalar Green's function

G1=i*g0.*(1-1../(k0*Rt).^2+i/k0./Rt)./Rt.^2;	
					% first term
G2=i*g0.*2..*(1../(k0*Rt).^2-i/k0./Rt)./Rt.^2;	
					% second term

G1xx=G1.*(Rt.^2-xt.^2);
G1xy=-G1.*xt.*yt;
G1xz=-G1.*xt.*zt;
G1yy=G1.*(Rt.^2-yt.^2);
G1yz=-G1.*yt.*zt;
G1zz=G1.*(Rt.^2-zt.^2);

% The rest of the first term Green's functions are not 
% needed:
%		G1yx=G1xy
%		G1zx=G1xz
% 		G1zy=G1yz

G2xx=G2.*xt.^2;
G2xy=G2.*xt.*yt;
G2xz=G2.*xt.*zt;
G2yy=G2.*yt.^2;
G2yz=G2.*yt.*zt;
G2zz=G2.*zt.^2;

% The rest of the second term Green's functions are not 
% needed:
%		G2yx=G2xy
%		G2zx=G2xz
% 		G2zy=G2yz

Gxx=G1xx+G2xx;
Gxy=G1xy+G2xy;
Gxz=G1xz+G2xz;
Gyy=G1yy+G2yy;
Gyz=G1yz+G2yz;
Gzz=G1zz+G2zz;

Hx=Gxx*Ms(:,1)+Gxy*Ms(:,2)+Gxz*Ms(:,3);   
			% Nf by 1, E x component
Hy=Gxy*Ms(:,1)+Gyy*Ms(:,2)+Gyz*Ms(:,3);  
			% Nf by 1, E y component
Hz=Gxz*Ms(:,1)+Gyz*Ms(:,2)+Gzz*Ms(:,3);  
			% Nf by 1, E z component

Hf=[Hx Hy Hz];		% Nf by 3 array, radiated E

%