function E=propxf01(rs,Ms,rf,k0)

% Reactive Near-Field Propagator

%	rs	Ns by 3 array, source position vectors
%	Ms	Ns by 3 array, source currents
% 	rf	Nf by 3 array, field position vectors
%	k0	wavenumber, radians/inch
%
%	Ns	number of source points
%	Nf	number of field poins
%

Ns=length(rs(:,1));		% number of source points
Nf=length(rf(:,1));		% number of field points

INs=ones(Ns,1);		% Ns by 1 array of ones
INf=ones(Nf,1);		% Nf by 1 array of ones	

xt=rf(:,1)*INs'-INf*rs(:,1)';	
		% Nf by Ns array, transport vector x components
yt=rf(:,2)*INs'-INf*rs(:,2)';	
		% Nf by Ns array, transport vector y components
zt=rf(:,3)*INs'-INf*rs(:,3)';	
		% Nf by Ns array, transport vector z components

Rt=sqrt(xt.^2+yt.^2+zt.^2);	
			% Nf by Ns array, transport vector lengths
g0=1/4/pi./Rt.*exp(i*k0*Rt);	
			% Nf by Ns array, scalar Green's functions

Gxy=-1../Rt.*g0.*zt./Rt;% Nf by Ns array, x from y Green's function
Gxz=1../Rt.*g0.*yt./Rt;	% Nf by Ns array, x from z Green's function
Gyz=-1../Rt.*g0.*xt./Rt;% Nf by Ns array, y from z Green's function

% The rest of the Green' functions are trivial or not needed, 
% they are:
%	Gxx=zeros(Nf,Ns)
%	Gyx=-Gxy
% 	Gyy=Gxx
%	Gzx=-Gxz
%	Gzy=-Gyz
%	Gzz=Gxx

Ex=Gxy*Ms(:,2)+Gxz*Ms(:,3);	
		% Nf by 1 array, x components of radiated field
Ey=-Gxy*Ms(:,1)+Gyz*Ms(:,3);	
		% Nf by 1 array, y components of radiated field
Ez=-Gxz*Ms(:,1)-Gyz*Ms(:,2);	
		% Nf by 1 array, z components of radiated field

Ef=[Ex Ey Ez];		% Nf by 3 array, radiated E field

%